Coverage for aipyapp/__version__.py: 100%

1# file generated by setuptools-scm

2# don't change, don't track in version control

3

4 __all__ = ["__version__", "__version_tuple__", "version", "version_tuple"]

5

6 TYPE_CHECKING = False

7 if TYPE_CHECKING:

8 from typing import Tuple

9 from typing import Union

10

11 VERSION_TUPLE = Tuple[Union[int, str], ...]

12 else:

13 VERSION_TUPLE = object

14

15 version: str

16 __version__: str

17 __version_tuple__: VERSION_TUPLE

18 version_tuple: VERSION_TUPLE

19

20 __version__ = version = '0.3.0b20'

21 __version_tuple__ = version_tuple = (0, 3, 0, 'b20')